package CoveredFile;
use strict;
use warnings;

sub covered_one {}
sub covered_two {}
sub covered_three {}

1;
__END__

=head2 Methods

=over

=item covered_one

Covered sub covered_one.

=back

=head2 covered_two

Covered sub covered_two.

=head2 covered_three

Covered sub covered_three.

=cut
